==> ncpfs_2.2.0.17.orig.tar.gz: ncpfs-2.2.0.17/acconfig.h <==
/* If you want native IP support, uncomment CONFIG_NATIVE_IP
   Do not forget that it is VERY ALPHA code, with almost no support
   Enable only if you are interested in NCP over IP and you want help
   me. -A ip.address is your friend. At this time you have to silently
   ignore Login to server XXXX as YYYY - think that XXXX is ip.address and
   not one taken from .nwclient. Also, if you have not .nwclient, you have
   to add -S DUMMY on commandline. */
#undef CONFIG_NATIVE_IP

/* If you do not want IPX support, comment CONFIG_NATIVE_IPX out...
   I cannot recommend doing it */
#undef CONFIG_NATIVE_IPX

/* If you want to include packet signature support uncomment this.
   If you are using 2.0.x Linux kernel, make sure that you also applied
   kernel patches. */
/* Change only through 'configure', copies of this value are in makefiles */
#undef SIGNATURES

/* If you want to include NDS support, define NDS_SUPPORT symbol */
/* Change only through 'configure', copies of this value are in makefiles */
#undef NDS_SUPPORT

/* If defined, support for Linux2.0.x is compiled in */
/* Change only through 'configure', copies of this value are in makefiles */
#undef MOUNT2

/* If defined, support for Linux2.1.x is compiled in */
/* Change only through 'configure', copies of this value are in makefiles */
#undef MOUNT3

/* If you want to trace ncp calls uncomment this. */
#undef NCP_TRACE_ENABLE

/* If you want to eat only one NDS connection. 
   Does not work at this time. */
#undef NDS_PRIVATEKEY

/* mount() and associated structures were not found...
   They are normally in <sys/mount.h> or <linux/fs.h> */
/* Change only through 'configure', copies of this value are in makefiles */
#undef NO_MOUNT_SUPPORT

/* neither net/if.h nor linux/if.h was found, so ipx_* will not build... */
/* Change only through 'configure', copies of this value are in makefiles */
#undef NO_NET_IF_SUPPORT

/* neither net/route.h nor linux/route.h was found ... */
/* Change only through 'configure', copies of this value are in makefiles */
#undef NO_NET_ROUTE_SUPPORT

/* Define if you have IPX header netipx/ipx.h */
#undef HAVE_NETIPX_IPX_H

/* Define if you have IPX header linux/ipx.h */
#undef HAVE_LINUX_IPX_H

/* Define it to (PF_IPX) if your headers do not define it */
#undef IPXPROTO_IPX

/* Define to 0x89E0 if your headers do not define it */
#undef SIOCPROTOPRIVATE

/* Define it to (SIOCPROTOPRIVATE) if your headers do not define it */
#undef SIOCAIPXITFCRT

/* Define it to (SIOCPROTOPRIVATE + 1) if your headers do not define it */
#undef SIOCAIPXPRISLT

/* Define it to (SIOCPROTOPRIVATE + 2) if your heeaders do not define it */
#undef SIOCIPXCFGDATA

/* Define it to unsigned int (32) if stddef.h does not define it */
#undef wchar_t

/* Define if you want enable NLS */
#undef ENABLE_NLS

/* Define if your system supports gettext */
#undef HAVE_GETTEXT

/* Define if your system supports catgets */
#undef HAVE_CATGETS

/* Define if your system has LC_MESSAGES */
#undef HAVE_LC_MESSAGES

/* Define if your system has stpcpy */
#undef HAVE_STPCPY

/* Package name: ncpfs */
#undef PACKAGE

/* Package version... */
#undef VERSION
#undef NCPFS_VERSION

/* Localedir name: $prefix/&at;DATADIRNAME&at;/locale */
#undef LOCALEDIR

/* Define when compiling for Linux kernel */
#undef USE_KERNEL

/* Define if we have working asm/atomic.h */
#undef HAVE_ASM_ATOMIC_H

/* Define if you need this for correct threading_MIT_POSIX_THREADS ... */
#undef _MIT_POSIX_THREADS

==> ncpfs_2.2.0.18.orig.tar.gz: ncpfs-2.2.0.18/acconfig.h <==
/* If you want native IP support, uncomment CONFIG_NATIVE_IP
   Do not forget that it is VERY ALPHA code, with almost no support
   Enable only if you are interested in NCP over IP and you want help
   me. -A ip.address is your friend. At this time you have to silently
   ignore Login to server XXXX as YYYY - think that XXXX is ip.address and
   not one taken from .nwclient. Also, if you have not .nwclient, you have
   to add -S DUMMY on commandline. */
#undef CONFIG_NATIVE_IP

/* If you do not want IPX support, comment CONFIG_NATIVE_IPX out...
   I cannot recommend doing it */
#undef CONFIG_NATIVE_IPX

/* If you want to include packet signature support uncomment this.
   If you are using 2.0.x Linux kernel, make sure that you also applied
   kernel patches. */
/* Change only through 'configure', copies of this value are in makefiles */
#undef SIGNATURES

/* If you want to include NDS support, define NDS_SUPPORT symbol */
/* Change only through 'configure', copies of this value are in makefiles */
#undef NDS_SUPPORT

/* If defined, support for Linux2.0.x is compiled in */
/* Change only through 'configure', copies of this value are in makefiles */
#undef MOUNT2

/* If defined, support for Linux2.1.x is compiled in */
/* Change only through 'configure', copies of this value are in makefiles */
#undef MOUNT3

/* If you want to trace ncp calls uncomment this. */
#undef NCP_TRACE_ENABLE

/* If you want to eat only one NDS connection. 
   Does not work at this time. */
#undef NDS_PRIVATEKEY

/* mount() and associated structures were not found...
   They are normally in <sys/mount.h> or <linux/fs.h> */
/* Change only through 'configure', copies of this value are in makefiles */
#undef NO_MOUNT_SUPPORT

/* neither net/if.h nor linux/if.h was found, so ipx_* will not build... */
/* Change only through 'configure', copies of this value are in makefiles */
#undef NO_NET_IF_SUPPORT

/* neither net/route.h nor linux/route.h was found ... */
/* Change only through 'configure', copies of this value are in makefiles */
#undef NO_NET_ROUTE_SUPPORT

/* Define if you have IPX header netipx/ipx.h */
#undef HAVE_NETIPX_IPX_H

/* Define if you have IPX header linux/ipx.h */
#undef HAVE_LINUX_IPX_H

/* Define it to (PF_IPX) if your headers do not define it */
#undef IPXPROTO_IPX

/* Define to 0x89E0 if your headers do not define it */
#undef SIOCPROTOPRIVATE

/* Define it to (SIOCPROTOPRIVATE) if your headers do not define it */
#undef SIOCAIPXITFCRT

/* Define it to (SIOCPROTOPRIVATE + 1) if your headers do not define it */
#undef SIOCAIPXPRISLT

/* Define it to (SIOCPROTOPRIVATE + 2) if your heeaders do not define it */
#undef SIOCIPXCFGDATA

/* Define it to unsigned int (32) if stddef.h does not define it */
#undef wchar_t

/* Define if you want enable NLS */
#undef ENABLE_NLS

/* Define if your system supports gettext */
#undef HAVE_GETTEXT

/* Define if your system supports catgets */
#undef HAVE_CATGETS

/* Define if your system has LC_MESSAGES */
#undef HAVE_LC_MESSAGES

/* Define if your system has stpcpy */
#undef HAVE_STPCPY

/* Package name: ncpfs */
#undef PACKAGE

/* Package version... */
#undef VERSION
#undef NCPFS_VERSION

/* Localedir name: $prefix/&at;DATADIRNAME&at;/locale */
#undef LOCALEDIR

/* Define when compiling for Linux kernel */
#undef USE_KERNEL

/* Define if we have working asm/atomic.h */
#undef HAVE_ASM_ATOMIC_H

/* Define if you need this for correct threading_MIT_POSIX_THREADS ... */
#undef _MIT_POSIX_THREADS

/* Define to 8 (big-endian) or 16 (32 bit little-endian except i386) or 32 (i386) */
#undef UNITSIZE
#undef MULTUNITSIZE
